@@ -13,7 +13,6 @@ from . import problem_list
 from . import profiler
 from . import problem
 from . import utils
-from . import fast
 
 __all__ = (*open_solvers.__all__,
            *bounded_solvers.__all__,
@@ -24,7 +23,6 @@ __all__ = (*open_solvers.__all__,
            *profiler.__all__,
            *jit_speed.__all__,
            'utils',
-           'fast',
 )
 
 from .jit_speed import *
@@ -34,4 +32,6 @@ from .iterative_solvers import *
 from .least_squares_iteration import *
 from .problem_list import *
 from .problem import *
-from .profiler import *
\ No newline at end of file
+from .profiler import *
+
+__version__ = '0.3.31'
\ No newline at end of file
