@@ -5,13 +5,19 @@ Created on Wed Nov 20 23:09:53 2019
 @author: yoelr
 """
 import numpy as np
-import matplotlib.pyplot as plt
 from copy import copy
 
 __all__ = ('Profiler',)
+     
+plt = None
+
+def _load_matplotlib(): # pragma: no cover
+    global plt
+    if not plt:
+        import matplotlib.pyplot as plt       
+    
             
-            
-class Archive:
+class Archive: # pragma: no cover
     __slots__ = ('name', 'xs', 'ys')
     
     def __init__(self, name, xs, ys):
@@ -53,7 +59,7 @@ class Archive:
               ")")
 
 
-class Profiler:
+class Profiler: # pragma: no cover
     __slots__ = ('f', 'xs', 'ys', 'active_archives', 'passed_cases', 'failed_cases')
     def __init__(self, f):
         self.f = f
@@ -84,7 +90,7 @@ class Profiler:
         return sum([len(archive) for archive in self.active_archives])
 
     def sizes(self):
-        return {archive.name: len(archive) for archive in self.archives}
+        return {archive.name: len(archive) for archive in self.active_archives}
     
     def activate_failed_archives(self):
         self.active_archives = self.failed_cases
@@ -95,7 +101,7 @@ class Profiler:
     def _plot_points(self, rxs, rys, offset, step):
         cycle = plt.rcParams['axes.prop_cycle']
         colors = cycle.by_key()['color']
-        archives = self.archives
+        archives = self.active_archives
         for color, archive in zip(colors, archives):
             xs = archive.xs
             ys = archive.ys + offset
@@ -107,8 +113,9 @@ class Profiler:
     def plot(self, title=None, args=(), markbounds=True,
              plot_outside_bounds=True, N=50, shade=True,
              remove_ticks=True):
+        _load_matplotlib()
         plt.figure()
-        archives = self.archives
+        archives = self.active_archives
         archives.sort(key=lambda x: x.size)
         x_mins = np.array([i.x_min for i in archives])
         x_maxs = np.array([i.x_max for i in archives])
